# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/stream_line_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import stream_line_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__line__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/video/v1/stream_line_service.proto\x12\x15yandex.cloud.video.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\'yandex/cloud/video/v1/stream_line.proto\".\n\x14GetStreamLineRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"u\n\x16ListStreamLinesRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\t\"k\n\x17ListStreamLinesResponse\x12\x37\n\x0cstream_lines\x18\x01 \x03(\x0b\x32!.yandex.cloud.video.v1.StreamLine\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\t\"\xd8\x05\n\x17\x43reateStreamLineRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x03 \x01(\t\x12K\n\x06labels\x18\xc8\x01 \x03(\x0b\x32:.yandex.cloud.video.v1.CreateStreamLineRequest.LabelsEntry\x12;\n\trtmp_push\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPushParamsH\x00\x12\x39\n\x08srt_push\x18\xe9\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPushParamsH\x00\x12;\n\trtmp_pull\x18\xea\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPullParamsH\x00\x12\x39\n\x08srt_pull\x18\xeb\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPullParamsH\x00\x12\x39\n\x08tcp_pull\x18\xec\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.TCPPullParamsH\x00\x12;\n\trtsp_pull\x18\xee\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTSPPullParamsH\x00\x12?\n\x0bmanual_line\x18\xd0\x0f \x01(\x0b\x32\'.yandex.cloud.video.v1.ManualLineParamsH\x01\x12;\n\tauto_line\x18\xd1\x0f \x01(\x0b\x32%.yandex.cloud.video.v1.AutoLineParamsH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cinput_paramsB\x12\n\x10line_type_params\"2\n\x18\x43reateStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"\xfa\x04\n\x17UpdateStreamLineRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x04 \x01(\t\x12K\n\x06labels\x18\xc8\x01 \x03(\x0b\x32:.yandex.cloud.video.v1.UpdateStreamLineRequest.LabelsEntry\x12;\n\trtmp_push\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPushParamsH\x00\x12\x39\n\x08srt_push\x18\xe9\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPushParamsH\x00\x12;\n\trtmp_pull\x18\xea\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPullParamsH\x00\x12\x39\n\x08srt_pull\x18\xeb\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPullParamsH\x00\x12\x39\n\x08tcp_pull\x18\xec\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.TCPPullParamsH\x00\x12;\n\trtsp_pull\x18\xee\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTSPPullParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cinput_params\"2\n\x18UpdateStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"1\n\x17\x44\x65leteStreamLineRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"\xb8\x01\n\x18PerformLineActionRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\x12:\n\x08\x61\x63tivate\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ActivateActionH\x00\x12>\n\ndeactivate\x18\xe9\x07 \x01(\x0b\x32\'.yandex.cloud.video.v1.DeactivateActionH\x00\x42\x08\n\x06\x61\x63tion\"3\n\x19PerformLineActionMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"\x10\n\x0eRTMPPushParams\"\x0f\n\rSRTPushParams\"\x1d\n\x0eRTMPPullParams\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x1c\n\rSRTPullParams\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x1c\n\rTCPPullParams\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x1d\n\x0eRTSPPullParams\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x12\n\x10ManualLineParams\"\x10\n\x0e\x41utoLineParams\"\x10\n\x0e\x41\x63tivateAction\"\x12\n\x10\x44\x65\x61\x63tivateAction\"-\n\x13GetStreamKeyRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"0\n\x16UpdateStreamKeyRequest\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"1\n\x17UpdateStreamKeyMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t2\x89\x08\n\x11StreamLineService\x12W\n\x03Get\x12+.yandex.cloud.video.v1.GetStreamLineRequest\x1a!.yandex.cloud.video.v1.StreamLine\"\x00\x12g\n\x04List\x12-.yandex.cloud.video.v1.ListStreamLinesRequest\x1a..yandex.cloud.video.v1.ListStreamLinesResponse\"\x00\x12\x87\x01\n\x06\x43reate\x12..yandex.cloud.video.v1.CreateStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"*\xb2\xd2*&\n\x18\x43reateStreamLineMetadata\x12\nStreamLine\x12\x87\x01\n\x06Update\x12..yandex.cloud.video.v1.UpdateStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"*\xb2\xd2*&\n\x18UpdateStreamLineMetadata\x12\nStreamLine\x12\x92\x01\n\x06\x44\x65lete\x12..yandex.cloud.video.v1.DeleteStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"5\xb2\xd2*1\n\x18\x44\x65leteStreamLineMetadata\x12\x15google.protobuf.Empty\x12\x90\x01\n\rPerformAction\x12/.yandex.cloud.video.v1.PerformLineActionRequest\x1a!.yandex.cloud.operation.Operation\"+\xb2\xd2*\'\n\x19PerformLineActionMetadata\x12\nStreamLine\x12\x62\n\x0cGetStreamKey\x12*.yandex.cloud.video.v1.GetStreamKeyRequest\x1a$.yandex.cloud.video.v1.PushStreamKey\"\x00\x12\x91\x01\n\x0fUpdateStreamKey\x12-.yandex.cloud.video.v1.UpdateStreamKeyRequest\x1a!.yandex.cloud.operation.Operation\",\xb2\xd2*(\n\x17UpdateStreamKeyMetadata\x12\rPushStreamKeyB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.stream_line_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _CREATESTREAMLINEREQUEST_LABELSENTRY._options = None
  _CREATESTREAMLINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESTREAMLINEREQUEST_LABELSENTRY._options = None
  _UPDATESTREAMLINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _STREAMLINESERVICE.methods_by_name['Create']._options = None
  _STREAMLINESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateStreamLineMetadata\022\nStreamLine'
  _STREAMLINESERVICE.methods_by_name['Update']._options = None
  _STREAMLINESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateStreamLineMetadata\022\nStreamLine'
  _STREAMLINESERVICE.methods_by_name['Delete']._options = None
  _STREAMLINESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteStreamLineMetadata\022\025google.protobuf.Empty'
  _STREAMLINESERVICE.methods_by_name['PerformAction']._options = None
  _STREAMLINESERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*\'\n\031PerformLineActionMetadata\022\nStreamLine'
  _STREAMLINESERVICE.methods_by_name['UpdateStreamKey']._options = None
  _STREAMLINESERVICE.methods_by_name['UpdateStreamKey']._serialized_options = b'\262\322*(\n\027UpdateStreamKeyMetadata\022\rPushStreamKey'
  _globals['_GETSTREAMLINEREQUEST']._serialized_start=223
  _globals['_GETSTREAMLINEREQUEST']._serialized_end=269
  _globals['_LISTSTREAMLINESREQUEST']._serialized_start=271
  _globals['_LISTSTREAMLINESREQUEST']._serialized_end=388
  _globals['_LISTSTREAMLINESRESPONSE']._serialized_start=390
  _globals['_LISTSTREAMLINESRESPONSE']._serialized_end=497
  _globals['_CREATESTREAMLINEREQUEST']._serialized_start=500
  _globals['_CREATESTREAMLINEREQUEST']._serialized_end=1228
  _globals['_CREATESTREAMLINEREQUEST_LABELSENTRY']._serialized_start=1147
  _globals['_CREATESTREAMLINEREQUEST_LABELSENTRY']._serialized_end=1192
  _globals['_CREATESTREAMLINEMETADATA']._serialized_start=1230
  _globals['_CREATESTREAMLINEMETADATA']._serialized_end=1280
  _globals['_UPDATESTREAMLINEREQUEST']._serialized_start=1283
  _globals['_UPDATESTREAMLINEREQUEST']._serialized_end=1917
  _globals['_UPDATESTREAMLINEREQUEST_LABELSENTRY']._serialized_start=1147
  _globals['_UPDATESTREAMLINEREQUEST_LABELSENTRY']._serialized_end=1192
  _globals['_UPDATESTREAMLINEMETADATA']._serialized_start=1919
  _globals['_UPDATESTREAMLINEMETADATA']._serialized_end=1969
  _globals['_DELETESTREAMLINEREQUEST']._serialized_start=1971
  _globals['_DELETESTREAMLINEREQUEST']._serialized_end=2020
  _globals['_DELETESTREAMLINEMETADATA']._serialized_start=2022
  _globals['_DELETESTREAMLINEMETADATA']._serialized_end=2072
  _globals['_PERFORMLINEACTIONREQUEST']._serialized_start=2075
  _globals['_PERFORMLINEACTIONREQUEST']._serialized_end=2259
  _globals['_PERFORMLINEACTIONMETADATA']._serialized_start=2261
  _globals['_PERFORMLINEACTIONMETADATA']._serialized_end=2312
  _globals['_RTMPPUSHPARAMS']._serialized_start=2314
  _globals['_RTMPPUSHPARAMS']._serialized_end=2330
  _globals['_SRTPUSHPARAMS']._serialized_start=2332
  _globals['_SRTPUSHPARAMS']._serialized_end=2347
  _globals['_RTMPPULLPARAMS']._serialized_start=2349
  _globals['_RTMPPULLPARAMS']._serialized_end=2378
  _globals['_SRTPULLPARAMS']._serialized_start=2380
  _globals['_SRTPULLPARAMS']._serialized_end=2408
  _globals['_TCPPULLPARAMS']._serialized_start=2410
  _globals['_TCPPULLPARAMS']._serialized_end=2438
  _globals['_RTSPPULLPARAMS']._serialized_start=2440
  _globals['_RTSPPULLPARAMS']._serialized_end=2469
  _globals['_MANUALLINEPARAMS']._serialized_start=2471
  _globals['_MANUALLINEPARAMS']._serialized_end=2489
  _globals['_AUTOLINEPARAMS']._serialized_start=2491
  _globals['_AUTOLINEPARAMS']._serialized_end=2507
  _globals['_ACTIVATEACTION']._serialized_start=2509
  _globals['_ACTIVATEACTION']._serialized_end=2525
  _globals['_DEACTIVATEACTION']._serialized_start=2527
  _globals['_DEACTIVATEACTION']._serialized_end=2545
  _globals['_GETSTREAMKEYREQUEST']._serialized_start=2547
  _globals['_GETSTREAMKEYREQUEST']._serialized_end=2592
  _globals['_UPDATESTREAMKEYREQUEST']._serialized_start=2594
  _globals['_UPDATESTREAMKEYREQUEST']._serialized_end=2642
  _globals['_UPDATESTREAMKEYMETADATA']._serialized_start=2644
  _globals['_UPDATESTREAMKEYMETADATA']._serialized_end=2693
  _globals['_STREAMLINESERVICE']._serialized_start=2696
  _globals['_STREAMLINESERVICE']._serialized_end=3729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1alpha/database.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/mdb/mysql/v1alpha/database.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1dyandex/cloud/validation.proto\",\n\x08\x44\x61tabase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"<\n\x0c\x44\x61tabaseSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63Bn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.database_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql'
  _DATABASESPEC.fields_by_name['name']._options = None
  _DATABASESPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASE']._serialized_start=112
  _globals['_DATABASE']._serialized_end=156
  _globals['_DATABASESPEC']._serialized_start=158
  _globals['_DATABASESPEC']._serialized_end=218
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/elasticsearch/v1/backup_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/elasticsearch/v1/backup.proto\"+\n\x10GetBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"s\n\x12ListBackupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"j\n\x13ListBackupsResponse\x12:\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.elasticsearch.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd1\x02\n\rBackupService\x12\x9c\x01\n\x03Get\x12\x33.yandex.cloud.mdb.elasticsearch.v1.GetBackupRequest\x1a).yandex.cloud.mdb.elasticsearch.v1.Backup\"5\x82\xd3\xe4\x93\x02/\x12-/managed-elasticsearch/v1/backups/{backup_id}\x12\xa0\x01\n\x04List\x12\x35.yandex.cloud.mdb.elasticsearch.v1.ListBackupsRequest\x1a\x36.yandex.cloud.mdb.elasticsearch.v1.ListBackupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-elasticsearch/v1/backupsB|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _GETBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BACKUPSERVICE.methods_by_name['Get']._options = None
  _BACKUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002/\022-/managed-elasticsearch/v1/backups/{backup_id}'
  _BACKUPSERVICE.methods_by_name['List']._options = None
  _BACKUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/managed-elasticsearch/v1/backups'
  _globals['_GETBACKUPREQUEST']._serialized_start=202
  _globals['_GETBACKUPREQUEST']._serialized_end=245
  _globals['_LISTBACKUPSREQUEST']._serialized_start=247
  _globals['_LISTBACKUPSREQUEST']._serialized_end=362
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=364
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=470
  _globals['_BACKUPSERVICE']._serialized_start=473
  _globals['_BACKUPSERVICE']._serialized_end=810
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.ocr.v1 import ocr_service_pb2 as yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class TextRecognitionServiceStub(object):
    """A set of methods for the Vision OCR service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Recognize = channel.unary_stream(
                '/yandex.cloud.ai.ocr.v1.TextRecognitionService/Recognize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.FromString,
                )


class TextRecognitionServiceServicer(object):
    """A set of methods for the Vision OCR service.
    """

    def Recognize(self, request, context):
        """To send the image for text recognition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextRecognitionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Recognize': grpc.unary_stream_rpc_method_handler(
                    servicer.Recognize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.ocr.v1.TextRecognitionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextRecognitionService(object):
    """A set of methods for the Vision OCR service.
    """

    @staticmethod
    def Recognize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.ocr.v1.TextRecognitionService/Recognize',
            yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class TextRecognitionAsyncServiceStub(object):
    """A set of methods for managing operations for asynchronous API requests.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Recognize = channel.unary_unary(
                '/yandex.cloud.ai.ocr.v1.TextRecognitionAsyncService/Recognize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetRecognition = channel.unary_stream(
                '/yandex.cloud.ai.ocr.v1.TextRecognitionAsyncService/GetRecognition',
                request_serializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.GetRecognitionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.FromString,
                )


class TextRecognitionAsyncServiceServicer(object):
    """A set of methods for managing operations for asynchronous API requests.
    """

    def Recognize(self, request, context):
        """To send the image for asynchronous text recognition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecognition(self, request, context):
        """To get recognition results.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextRecognitionAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Recognize': grpc.unary_unary_rpc_method_handler(
                    servicer.Recognize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetRecognition': grpc.unary_stream_rpc_method_handler(
                    servicer.GetRecognition,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.GetRecognitionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.ocr.v1.TextRecognitionAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextRecognitionAsyncService(object):
    """A set of methods for managing operations for asynchronous API requests.
    """

    @staticmethod
    def Recognize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.ocr.v1.TextRecognitionAsyncService/Recognize',
            yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecognition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.ocr.v1.TextRecognitionAsyncService/GetRecognition',
            yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.GetRecognitionRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__service__pb2.RecognizeTextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import os_login_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2


class OsLoginServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/GetSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginSettings.FromString,
                )
        self.UpdateSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/UpdateSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetProfile = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/GetProfile',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginProfileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginProfile.FromString,
                )
        self.ListProfiles = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/ListProfiles',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesResponse.FromString,
                )
        self.CreateProfile = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/CreateProfile',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.CreateOsLoginProfileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateProfile = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/UpdateProfile',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginProfileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.SetDefaultProfile = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/SetDefaultProfile',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.SetDefaultOsLoginProfileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteProfile = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OsLoginService/DeleteProfile',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.DeleteOsLoginProfileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class OsLoginServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetSettings(self, request, context):
        """OsLogin settings
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProfile(self, request, context):
        """OsLogin Profiles
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProfiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultProfile(self, request, context):
        """Sets a profile as a default for the subject assigned to this profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OsLoginServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginSettings.SerializeToString,
            ),
            'UpdateSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProfile,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginProfileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginProfile.SerializeToString,
            ),
            'ListProfiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProfiles,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesResponse.SerializeToString,
            ),
            'CreateProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProfile,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.CreateOsLoginProfileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProfile,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginProfileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetDefaultProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultProfile,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.SetDefaultOsLoginProfileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProfile,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.DeleteOsLoginProfileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.OsLoginService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OsLoginService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/GetSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginSettings.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/UpdateSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/GetProfile',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.GetOsLoginProfileRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.OsLoginProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProfiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/ListProfiles',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.ListOsLoginProfilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/CreateProfile',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.CreateOsLoginProfileRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/UpdateProfile',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.UpdateOsLoginProfileRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/SetDefaultProfile',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.SetDefaultOsLoginProfileRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OsLoginService/DeleteProfile',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_os__login__service__pb2.DeleteOsLoginProfileRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/loadtesting/agent/v1/agent_registration_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1cgoogle/api/annotations.proto\".\n\x0fRegisterRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\"-\n\x10RegisterResponse\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\"s\n\x1c\x45xternalAgentRegisterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\ragent_version\x18\x04 \x01(\t\":\n\x1d\x45xternalAgentRegisterMetadata\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t2\xb2\x03\n\x18\x41gentRegistrationService\x12\xa5\x01\n\x08Register\x12\x32.yandex.cloud.loadtesting.agent.v1.RegisterRequest\x1a\x33.yandex.cloud.loadtesting.agent.v1.RegisterResponse\"0\x82\xd3\xe4\x93\x02*\"%/loadtesting/agent/v1/agents/register:\x01*\x12\xed\x01\n\x15\x45xternalAgentRegister\x12?.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*.\n\x1d\x45xternalAgentRegisterMetadata\x12\rAgentInstance\x82\xd3\xe4\x93\x02\x38\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _AGENTREGISTRATIONSERVICE.methods_by_name['Register']._options = None
  _AGENTREGISTRATIONSERVICE.methods_by_name['Register']._serialized_options = b'\202\323\344\223\002*\"%/loadtesting/agent/v1/agents/register:\001*'
  _AGENTREGISTRATIONSERVICE.methods_by_name['ExternalAgentRegister']._options = None
  _AGENTREGISTRATIONSERVICE.methods_by_name['ExternalAgentRegister']._serialized_options = b'\262\322*.\n\035ExternalAgentRegisterMetadata\022\rAgentInstance\202\323\344\223\0028\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\001*'
  _globals['_REGISTERREQUEST']._serialized_start=209
  _globals['_REGISTERREQUEST']._serialized_end=255
  _globals['_REGISTERRESPONSE']._serialized_start=257
  _globals['_REGISTERRESPONSE']._serialized_end=302
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_start=304
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_end=419
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_start=421
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_end=479
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_start=482
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_end=916
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import thumbnail_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2


class ThumbnailServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.BatchGenerateDownloadURLs = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
                )
        self.GenerateUploadURL = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
                )


class ThumbnailServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def List(self, request, context):
        """List thumbnails for channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Create thumbnail.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGenerateDownloadURLs(self, request, context):
        """Generate urls for download images.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateUploadURL(self, request, context):
        """Generate url for upload image.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ThumbnailServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchGenerateDownloadURLs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGenerateDownloadURLs,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.SerializeToString,
            ),
            'GenerateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateUploadURL,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.ThumbnailService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ThumbnailService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGenerateDownloadURLs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.backup.v1 import backup_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_backup__pb2
from yandex.cloud.backup.v1 import backup_service_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class BackupServiceStub(object):
    """A set of methods for managing [backups](/docs/backup/concepts/backup).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/List',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsResponse.FromString,
                )
        self.ListArchives = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/ListArchives',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesResponse.FromString,
                )
        self.ListFiles = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/ListFiles',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/Get',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.GetBackupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__pb2.Backup.FromString,
                )
        self.StartRecovery = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/StartRecovery',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartRecoveryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.StartFilesRecovery = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/StartFilesRecovery',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartFilesRecoveryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.backup.v1.BackupService/Delete',
                request_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.DeleteBackupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class BackupServiceServicer(object):
    """A set of methods for managing [backups](/docs/backup/concepts/backup).
    """

    def List(self, request, context):
        """List backups using filters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArchives(self, request, context):
        """List archives that holds backups for specified folder or
        specified [Compute Cloud instance](/docs/backup/concepts/vm-connection#os).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFiles(self, request, context):
        """ListFiles of the backup.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get backup by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRecovery(self, request, context):
        """Start recovery process of specified backup to specific Compute Cloud instance.

        For details, see [Restoring a VM from a backup](/docs/backup/operations/backup-vm/recover).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartFilesRecovery(self, request, context):
        """StartFilesRecovery runs recovery process of selected files to specific Compute Cloud instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete specific backup.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BackupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsResponse.SerializeToString,
            ),
            'ListArchives': grpc.unary_unary_rpc_method_handler(
                    servicer.ListArchives,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesResponse.SerializeToString,
            ),
            'ListFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFiles,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.GetBackupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__pb2.Backup.SerializeToString,
            ),
            'StartRecovery': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRecovery,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartRecoveryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'StartFilesRecovery': grpc.unary_unary_rpc_method_handler(
                    servicer.StartFilesRecovery,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartFilesRecoveryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.DeleteBackupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.backup.v1.BackupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BackupService(object):
    """A set of methods for managing [backups](/docs/backup/concepts/backup).
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/List',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsRequest.SerializeToString,
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListBackupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListArchives(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/ListArchives',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesRequest.SerializeToString,
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListArchivesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/ListFiles',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesRequest.SerializeToString,
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.ListFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/Get',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.GetBackupRequest.SerializeToString,
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__pb2.Backup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRecovery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/StartRecovery',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartRecoveryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartFilesRecovery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/StartFilesRecovery',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.StartFilesRecoveryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.backup.v1.BackupService/Delete',
            yandex_dot_cloud_dot_backup_dot_v1_dot_backup__service__pb2.DeleteBackupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/zone.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/compute/v1/zone.proto\x12\x17yandex.cloud.compute.v1\"\x8f\x01\n\x04Zone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tregion_id\x18\x02 \x01(\t\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32$.yandex.cloud.compute.v1.Zone.Status\"2\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.zone_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_ZONE']._serialized_start=64
  _globals['_ZONE']._serialized_end=207
  _globals['_ZONE_STATUS']._serialized_start=157
  _globals['_ZONE_STATUS']._serialized_end=207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/stream_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import stream_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/video/v1/stream_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\"yandex/cloud/video/v1/stream.proto\"%\n\x10GetStreamRequest\x12\x11\n\tstream_id\x18\x01 \x01(\t\"q\n\x12ListStreamsRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\t\"^\n\x13ListStreamsResponse\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Stream\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\t\"\xf4\x02\n\x13\x43reateStreamRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07line_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12G\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x36.yandex.cloud.video.v1.CreateStreamRequest.LabelsEntry\x12;\n\ton_demand\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.OnDemandParamsH\x00\x12:\n\x08schedule\x18\xe9\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ScheduleParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0bstream_type\"\x10\n\x0eOnDemandParams\"q\n\x0eScheduleParams\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inish_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\")\n\x14\x43reateStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"\xa3\x03\n\x13UpdateStreamRequest\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0f\n\x07line_id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x06 \x01(\t\x12G\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x36.yandex.cloud.video.v1.UpdateStreamRequest.LabelsEntry\x12;\n\ton_demand\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.OnDemandParamsH\x00\x12:\n\x08schedule\x18\xe9\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ScheduleParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0bstream_type\")\n\x14UpdateStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"(\n\x13\x44\x65leteStreamRequest\x12\x11\n\tstream_id\x18\x01 \x01(\t\")\n\x14\x44\x65leteStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"\xaf\x01\n\x1aPerformStreamActionRequest\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12\x38\n\x07publish\x18\xe8\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.PublishActionH\x00\x12\x32\n\x04stop\x18\xea\x07 \x01(\x0b\x32!.yandex.cloud.video.v1.StopActionH\x00\x42\x08\n\x06\x61\x63tionJ\x06\x08\xe9\x07\x10\xea\x07\"\x0f\n\rPublishAction\"\x0c\n\nStopAction\"0\n\x1bPerformStreamActionMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t2\xdb\x05\n\rStreamService\x12O\n\x03Get\x12\'.yandex.cloud.video.v1.GetStreamRequest\x1a\x1d.yandex.cloud.video.v1.Stream\"\x00\x12_\n\x04List\x12).yandex.cloud.video.v1.ListStreamsRequest\x1a*.yandex.cloud.video.v1.ListStreamsResponse\"\x00\x12{\n\x06\x43reate\x12*.yandex.cloud.video.v1.CreateStreamRequest\x1a!.yandex.cloud.operation.Operation\"\"\xb2\xd2*\x1e\n\x14\x43reateStreamMetadata\x12\x06Stream\x12{\n\x06Update\x12*.yandex.cloud.video.v1.UpdateStreamRequest\x1a!.yandex.cloud.operation.Operation\"\"\xb2\xd2*\x1e\n\x14UpdateStreamMetadata\x12\x06Stream\x12\x8a\x01\n\x06\x44\x65lete\x12*.yandex.cloud.video.v1.DeleteStreamRequest\x1a!.yandex.cloud.operation.Operation\"1\xb2\xd2*-\n\x14\x44\x65leteStreamMetadata\x12\x15google.protobuf.Empty\x12\x90\x01\n\rPerformAction\x12\x31.yandex.cloud.video.v1.PerformStreamActionRequest\x1a!.yandex.cloud.operation.Operation\")\xb2\xd2*%\n\x1bPerformStreamActionMetadata\x12\x06StreamB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.stream_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _CREATESTREAMREQUEST_LABELSENTRY._options = None
  _CREATESTREAMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESTREAMREQUEST_LABELSENTRY._options = None
  _UPDATESTREAMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _STREAMSERVICE.methods_by_name['Create']._options = None
  _STREAMSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateStreamMetadata\022\006Stream'
  _STREAMSERVICE.methods_by_name['Update']._options = None
  _STREAMSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateStreamMetadata\022\006Stream'
  _STREAMSERVICE.methods_by_name['Delete']._options = None
  _STREAMSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteStreamMetadata\022\025google.protobuf.Empty'
  _STREAMSERVICE.methods_by_name['PerformAction']._options = None
  _STREAMSERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*%\n\033PerformStreamActionMetadata\022\006Stream'
  _globals['_GETSTREAMREQUEST']._serialized_start=246
  _globals['_GETSTREAMREQUEST']._serialized_end=283
  _globals['_LISTSTREAMSREQUEST']._serialized_start=285
  _globals['_LISTSTREAMSREQUEST']._serialized_end=398
  _globals['_LISTSTREAMSRESPONSE']._serialized_start=400
  _globals['_LISTSTREAMSRESPONSE']._serialized_end=494
  _globals['_CREATESTREAMREQUEST']._serialized_start=497
  _globals['_CREATESTREAMREQUEST']._serialized_end=869
  _globals['_CREATESTREAMREQUEST_LABELSENTRY']._serialized_start=809
  _globals['_CREATESTREAMREQUEST_LABELSENTRY']._serialized_end=854
  _globals['_ONDEMANDPARAMS']._serialized_start=871
  _globals['_ONDEMANDPARAMS']._serialized_end=887
  _globals['_SCHEDULEPARAMS']._serialized_start=889
  _globals['_SCHEDULEPARAMS']._serialized_end=1002
  _globals['_CREATESTREAMMETADATA']._serialized_start=1004
  _globals['_CREATESTREAMMETADATA']._serialized_end=1045
  _globals['_UPDATESTREAMREQUEST']._serialized_start=1048
  _globals['_UPDATESTREAMREQUEST']._serialized_end=1467
  _globals['_UPDATESTREAMREQUEST_LABELSENTRY']._serialized_start=809
  _globals['_UPDATESTREAMREQUEST_LABELSENTRY']._serialized_end=854
  _globals['_UPDATESTREAMMETADATA']._serialized_start=1469
  _globals['_UPDATESTREAMMETADATA']._serialized_end=1510
  _globals['_DELETESTREAMREQUEST']._serialized_start=1512
  _globals['_DELETESTREAMREQUEST']._serialized_end=1552
  _globals['_DELETESTREAMMETADATA']._serialized_start=1554
  _globals['_DELETESTREAMMETADATA']._serialized_end=1595
  _globals['_PERFORMSTREAMACTIONREQUEST']._serialized_start=1598
  _globals['_PERFORMSTREAMACTIONREQUEST']._serialized_end=1773
  _globals['_PUBLISHACTION']._serialized_start=1775
  _globals['_PUBLISHACTION']._serialized_end=1790
  _globals['_STOPACTION']._serialized_start=1792
  _globals['_STOPACTION']._serialized_end=1804
  _globals['_PERFORMSTREAMACTIONMETADATA']._serialized_start=1806
  _globals['_PERFORMSTREAMACTIONMETADATA']._serialized_end=1854
  _globals['_STREAMSERVICE']._serialized_start=1857
  _globals['_STREAMSERVICE']._serialized_end=2588
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.billing.v1 import billing_account_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2
from yandex.cloud.billing.v1 import billing_account_service_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class BillingAccountServiceStub(object):
    """A set of methods for managing BillingAccount resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/Get',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/List',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.FromString,
                )
        self.ListBillableObjectBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/ListBillableObjectBindings',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.FromString,
                )
        self.BindBillableObject = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/BindBillableObject',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class BillingAccountServiceServicer(object):
    """A set of methods for managing BillingAccount resources.
    """

    def Get(self, request, context):
        """Returns the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of billing accounts available for current user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBillableObjectBindings(self, request, context):
        """Retrieves the list of billable object bindings associated with the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BindBillableObject(self, request, context):
        """Binds billable object to the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists access bindings for the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BillingAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.SerializeToString,
            ),
            'ListBillableObjectBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBillableObjectBindings,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.SerializeToString,
            ),
            'BindBillableObject': grpc.unary_unary_rpc_method_handler(
                    servicer.BindBillableObject,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.billing.v1.BillingAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BillingAccountService(object):
    """A set of methods for managing BillingAccount resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/Get',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/List',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBillableObjectBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/ListBillableObjectBindings',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BindBillableObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/BindBillableObject',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/api_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/iam/v1/api_key.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa7\x01\n\x06\x41piKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12service_account_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x30\n\x0clast_used_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.api_key_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_APIKEY']._serialized_start=92
  _globals['_APIKEY']._serialized_end=259
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/channel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/video/v1/channel.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x02\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x06labels\x18\xc8\x01 \x03(\x0b\x32*.yandex.cloud.video.v1.Channel.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.channel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _CHANNEL_LABELSENTRY._options = None
  _CHANNEL_LABELSENTRY._serialized_options = b'8\001'
  _globals['_CHANNEL']._serialized_start=96
  _globals['_CHANNEL']._serialized_end=382
  _globals['_CHANNEL_LABELSENTRY']._serialized_start=337
  _globals['_CHANNEL_LABELSENTRY']._serialized_end=382
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.mdb.postgresql.v1 import perf_diag_service_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2


class PerformanceDiagnosticsServiceStub(object):
    """A set of methods for PostgreSQL performance diagnostics.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRawSessionStates = channel.unary_unary(
                '/yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService/ListRawSessionStates',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesResponse.FromString,
                )
        self.ListRawStatements = channel.unary_unary(
                '/yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService/ListRawStatements',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsResponse.FromString,
                )


class PerformanceDiagnosticsServiceServicer(object):
    """A set of methods for PostgreSQL performance diagnostics.
    """

    def ListRawSessionStates(self, request, context):
        """Retrieves raw statistics on sessions. Corresponds to the [pg_stat_activity view](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRawStatements(self, request, context):
        """Retrieves statistics on planning and execution of SQL statements (queries).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PerformanceDiagnosticsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRawSessionStates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRawSessionStates,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesResponse.SerializeToString,
            ),
            'ListRawStatements': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRawStatements,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PerformanceDiagnosticsService(object):
    """A set of methods for PostgreSQL performance diagnostics.
    """

    @staticmethod
    def ListRawSessionStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService/ListRawSessionStates',
            yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawSessionStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRawStatements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService/ListRawStatements',
            yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__service__pb2.ListRawStatementsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
